Welcome to Interact’s documentation! — Interact documentation

# Welcome to Interact’s documentation!

Contents:

- Getting Started
  - Core Concept
  - Example Usage
- Base Classes
  - `Handler`
  - `HandlerChain`
  - `History`
  - `Message`
  - `handler()`
- Handler Classes
  - `AssignRole`
  - `BatchInputOpenAiLLM`
  - `OpenAiLLM`
  - `RetryHandlerChain`
  - `SimilarityRetriever`
- Retrieval
  - `EncoderType`
  - `Record`
  - `SimpleRecord`
  - `VectorDB`
  - `FaissIndexDB`
- Examples
  - comapny_name_and_tagline
  - company_name_w_decorator
  - handler_chain_uses
  - message_as_string
  - rag_example

## Interact

A simple python library to interact and build applications with Large Language Models.

## Installation

    pip install -U "interact @ git+https://github.com/pritam-dey3/Interact.git"

or, if you use faiss for similarity search

    pip install -U "interact[faiss] @ git+https://github.com/pritam-dey3/Interact.git"

Start learning about Interact by reading the Getting Started guide.

## Why Interact?

Applications with Large Language Models can get complex very quickly. You need more customizability and control over the prompts and their execution to satisfactorily build an application.

`Interact` was created with simplicity and scalability in mind. The core concepts of `Message` s, `Handler` s, and `Cascade` s are simple to understand and give You the power to build complex applications with ease.

More popular alternatives like `langchain` get frustrating to use when you want to customize either the process or the prompts according to your needs. `Interact` gives you control while maintaining a very simple and intuitive API.